Memory Management (Deprecated)#

Warning

The Memory API functions are not recommended for use in new code, and are provided for backwards compatibility with code written for Numba-CUDA. It is recommended that applications pass PyTorch Tensors or CuPy arrays to kernels instead.

Device Objects#